==> gnubg_1.06.001.orig.tar.gz: gnubg-1.06.001/matchid.h <==
/*
 * matchid.h
 *
 * by Joern Thyssen <jthyssen@dk.ibm.com>, 2002
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 3 or later of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: matchid.h,v 1.17 2016/08/24 21:58:36 plm Exp $
 */

#ifndef MATCHID_H
#define MATCHID_H

#define L_MATCHID 12

typedef struct {
    int anDice[2];
    int fTurn;
    int fResigned;
    int fDoubled;
    gamestate gs;
} posinfo;

extern int
 LogCube(int n);

extern char *MatchID(const unsigned int anDice[2],
                     const int fTurn,
                     const int fResigned,
                     const int fDoubled,
                     const int fMove,
                     const int fCubeOwner,
                     const int fCrawford, const int nMatchTo, const int anScore[2], const int nCube,
                     const int fJacoby, const gamestate gs);

extern char *MatchIDFromKey(unsigned char auchKey[9]);

extern int
MatchFromID(unsigned int anDice[2],
            int *pfTurn,
            int *pfResigned,
            int *pfDoubled, int *pfMove, int *pfCubeOwner, int *pfCrawford, int *pnMatchTo, int anScore[2], int *pnCube,
            int *pfJacoby, gamestate * pgs, const char *szMatchID);

extern char *MatchIDFromMatchState(const matchstate * pms);

#endif

==> gnubg_1.07.001.orig.tar.gz: gnubg-1.07.001/matchid.h <==
/*
 * Copyright (C) 2002 Joern Thyssen <jthyssen@dk.ibm.com>
 * Copyright (C) 2008-2013 the AUTHORS
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * $Id: matchid.h,v 1.19 2021/12/18 23:30:42 plm Exp $
 */

#ifndef MATCHID_H
#define MATCHID_H

#define L_MATCHID 12

typedef struct {
    int anDice[2];
    int fTurn;
    int fResigned;
    int fDoubled;
    gamestate gs;
} posinfo;

extern int LogCube(int n);

extern char *MatchID(const unsigned int anDice[2],
                     const int fTurn,
                     const int fResigned,
                     const int fDoubled,
                     const int fMove,
                     const int fCubeOwner,
                     const int fCrawford, const int nMatchTo, const int anScore[2], const int nCube,
                     const int fJacoby, const gamestate gs);

extern int MatchFromID(unsigned int anDice[2],
            int *pfTurn,
            int *pfResigned,
            int *pfDoubled, int *pfMove, int *pfCubeOwner, int *pfCrawford, int *pnMatchTo, int anScore[2], int *pnCube,
            int *pfJacoby, gamestate * pgs, const char *szMatchID);

extern char *MatchIDFromMatchState(const matchstate * pms);

#endif
